#include <iostream>
#include <type_traits>

class Base1 {
public:
    void show() const { std::cout << "Base1\n"; }
};

class Base2 {
public:
    void display() const { std::cout << "Base2\n"; }
};

template<typename T, typename = void>
struct has_show : std::false_type {};

template<typename T>
struct has_show<T, std::void_t<decltype(std::declval<T>().show())>> : std::true_type {};

template<typename T, typename = void>
struct has_display : std::false_type {};

template<typename T>
struct has_display<T, std::void_t<decltype(std::declval<T>().display())>> : std::true_type {};

template<typename... Bases>
class Derived : public Bases... {
public:
    void showAll() const {
        (callShow<Bases>(), ...);
    }

    void displayAll() const {
        (callDisplay<Bases>(), ...);
    }

private:
    template<typename T>
    void callShow() const {
        if constexpr (has_show<T>::value) {
            T::show();
        }
    }

    template<typename T>
    void callDisplay() const {
        if constexpr (has_display<T>::value) {
            T::display();
        }
    }
};

int main() {
    Derived<Base1, Base2> obj;
    obj.showAll();    // Calls Base1::show()
    obj.displayAll(); // Calls Base2::display()
    return 0;
}

